********************************
********************************
********************************
*Antynian Bertoni Corazzini
*This file by Marco Bertoni
*First version: 3 September 2019
*This version:  4 May 2020

********************************
********************************
********************************
*File 2
*Data analysis
********************************
********************************
********************************
cls
*Marco path
cd "C:\Users\marco.bertoni\Dropbox\screening armenia\Social Science and Medicine\datawork\"
*log
cap log close
log using analysis_ssm.txt, text replace
qui{
********************************
********************************
********************************
*set stata details for randomization
version 15
set matsize 11000
set seed 123456789

clear
import delimited "anonymize\armenian_data_ssm.csv"

lab var id "anonymous individual id"
lab var hid "anonymous hospital id"
lab var gpid "anonymous GP id"
lab var firstin "Born since May 1st 1987"
lab var outcome_correct "OUTCOME: has attended the screening"
lab var age_today "Age at randomization"
lab var urban "Lives in an urban area"
lab var qob1 "Born in Q1"
lab var qob2 "Born in Q2"
lab var qob3 "Born in Q3"
lab var qob4 "Born in Q4"
lab var w1 "Invited in week 1"
lab var w2 "Invited in week 2"
lab var w3 "Invited in week 3"
lab var w4 "Invited in week 4"
lab var w5 "Invited in week 5"
lab var w6 "Invited in week 6"
lab var invited "An invitation letter was dispatched"
lab var letterr "An invitation letter was received"
lab var i "Only letter dispatched"
lab var r  "Letter and reminder dispatched"
lab var lr "Only letter dispatched - letter received"
lab var lrr "Letter and reminder dispatched - both received"
lab def treatment 1 "NeutLNoR" 2 "NegLNoR" 3 "OthLNoR" 4 "NeutLNeutR" 5 "NeutLNegR" 6 "NeutLOthR" 7 "NegLNegR" 8 "OthLOthR" 9 "NoLNoR"
lab val treatment treatment
lab var treatment "Treatment type (9 cat) dispatched"
lab val tlr treatment
lab var tlr "Intended treatment type (9 cat) received"

*define type of letter and reminder interactions
fvset base 9 tlr
fvset base 9 treatment
preserve
*FIGURE
ge k = treatment
recode k (9=0)
replace k = k+1
lab def f 1 "No Invitation" 2 "Neutral Letter No Reminder" 3 "Negative Letter No Reminder" 4 "Other-regarding Letter No Reminder" 5 "Neutral Letter Neutral Reminder" 6 "Neutral Letter Negative Reminder" 7 "Neutral Letter Other-regarding Reminder" 8 "Negative Letter Negative Reminder" 9 "Other-regarding Letter Other-regarding Reminder" 
lab val k f

gen g = 1
replace g = 2 if k>1
replace g = 3 if k>4
gen u = k 
expand 3 if _n==1, gen(p)
replace u = u+1 if k>1
replace u = u+1 if k>4
replace u = 2 if _n==2
replace u = 6 if _n==3
ta u

lab def u 1 "No Letter Control Group" 2 "" 3 "Neutral Letter, No Reminder" 4 "Negative Letter, No Reminder" ///
		  5 "Other-regarding Letter, No Reminder" 6 "" 7 "Neutral Letter, Neutral Reminder" 8 "Neutral Letter, Negative Reminder" ///
		  9 "Neutral Letter, Other-regarding Reminder" 10 "Negative Letter, Negative Reminder" 11 "Other-regarding Letter, Other-regarding Reminder" 
lab val u u

cibar outcome_correct, over(u) ///
ciopts(lcolor(black)) baropts(lcolor(black)) ///
barcol(gs16 gs16 dkorange red maroon gs13 eltblue ebblue ltblue blue dknavy) ///
graphopts(graphregion(fcolor(white)) ytitle("% screened") legend(order(1 "No Letter Control Group" " " 3 "Neutral Letter, No Reminder" 4 "Negative Letter, No Reminder" ///
		  5 "Other-regarding Letter, No Reminder"  " " 7 "Neutral Letter, Neutral Reminder" 8 "Neutral Letter, Negative Reminder" ///
		  9 "Neutral Letter, Other-regarding Reminder" 10 "Negative Letter, Negative Reminder" 11 "Other-regarding Letter, Other-regarding Reminder") ///
		  symplacement(north) col(1)) saving(Fig2.gph, replace))
restore

****************************
*table 1. Balancing of individual pre-determined observable characteristics across treatment groups
noi dis "1. Balancing of individual pre-determined observable characteristics across treatment groups"
capture erase TabS1.txt
capture erase TabS1.xls

foreach var of varlist age_today urban qob2-qob4 {

	noi reg `var' i.treatment i.gpid, robust
	noi testparm i.treatment
	local pval = r(p)
	noi su `var'  if treatment==9
	local mean = r(mean)
	outreg2 using TabS1.xls, excel append dec(3) nocon nor2 keep(1.treatment 2.treatment 3.treatment 4.treatment 5.treatment 6.treatment 7.treatment 8.treatment 9.treatment) addstat(f-test, `pval', mean control, `mean')
}

capture erase TabS1.txt

*******************************
*Table 2.	Balancing of invitation week across treatment groups within the invited pool.
noi dis "2. Balancing of invitation week across treatment groups within the invited pool."
capture erase TabS2.txt
capture erase TabS2.xls
fvset base 1 treatment
foreach var of varlist w2-w6{

	noi reg `var' i.treatment i.gpid if invited, robust
	noi testparm i.treatment
	local pval = r(p)
	noi su `var' if treatment==1
	local mean = r(mean)
	outreg2 using TabS2.xls, excel append dec(3) nocon nor2 keep(1.treatment 2.treatment 3.treatment 4.treatment 5.treatment 6.treatment 7.treatment 8.treatment) addstat(f-test, `pval', mean control, `mean')
	
}

capture erase TabS2.txt

fvset base 9 treatment

*now I twist the specifications

*************
*TABLE 1 col 2 and 3. The effects of invitation letters and of letter and reminder combinations on take-up
noi dis "Tab 3 col 2 The effects of invitation letters and of letter and reminder combinations on take-up"

capture erase Tab1Col23.txt
capture erase Tab1Col23.xls

noi dis "ITT"
noi areg outcome_correct invited  r, robust absorb(gpid)
noi test invited r
local pj = r(p)
noi su outcome_correct if invited==0
local mean = r(mean)
outreg2 using Tab1Col23.xls, excel append dec(3) nocon nor2 keep(invited r) ///
addstat("P-value joint", `pj', "Mean control group", `mean') 

noi dis "Tab 1 col 3 The effects of invitation letters and of letter and reminder combinations on take-up"

noi dis "TOT"
noi ivreghdfe outcome_correct (letterr lrr=invited r) , robust absorb(gpid) ffirst 
noi test letterr lrr
local pj = r(p)
local f =  e(rkf)
noi su outcome_correct if invited==0
local mean = r(mean)
outreg2 using Tab1Col23.xls, excel append dec(3) nocon nor2 keep(letterr lrr) ///
addstat("P-value joint", `pj', "Mean control group", `mean', "KP F-stat", `f')

capture erase Tab1Col23.txt

*********
*Table S1
*first stages
capture erase Tab2.txt
capture erase Tab2.xls

noi reghdfe letterr invited r , vce(robust) absorb(gpid)  
outreg2 using Tab2.xls, excel append dec(3) nocon nor2 keep(invited r) 
noi reghdfe lrr invited r , vce(robust) absorb(gpid) 
outreg2 using Tab2.xls, excel append dec(3) nocon nor2 keep(invited r) 

capture erase Tab2.txt
 



***********************
*Table 1 col 1. The effects of each treatment on screening participation

noi dis "Tab 1 col 1 The effects of each treatment on screening participation"


capture erase Tab1Col1.txt
capture erase Tab1Col1.xls

*invited
capture drop invited_*
ge invited_neg_no_rem = invited*(treat==2)
ge invited_oth_no_rem = invited*(treat==3)
ge invited_rem = invited*(treat==4|treat==5|treat==6|treat==7|treat==8)
ge invited_rem_neg = invited*(treat==5)
ge invited_rem_oth = invited*(treat==6)
ge invited_neg_rem_neg = invited*(treat==7)
ge invited_oth_rem_oth = invited*(treat==8)

noi areg outcome_correct invited invited_neg_no_rem invited_oth_no_rem invited_rem invited_rem_neg invited_rem_oth invited_neg_rem_neg invited_oth_rem_oth, robust absorb(gpid)
noi test invited_neg_no_rem = invited_oth_no_rem = invited_rem_neg=invited_rem=invited_rem_oth=invited_neg_rem_neg=invited_oth_rem_oth=0
noi test invited_neg_no_rem = invited_oth_no_rem = 0
noi test invited_rem_neg=invited_rem_oth=invited_neg_rem_neg=invited_oth_rem_oth=0

outreg2 using Tab1Col1.xls, excel append dec(3) nocon nor2 label ///
addstat("Mean control group", `mean')

capture erase Tab1Col1.txt

*intended treatment received
ge itr = 0
replace itr = 1 if (i==1&lr==1)|(r==1&lrr==1)

ta treat itr, row 

cap drop old
qui ge  old= age>=50
noi dis "ITR and Xs"
noi ta itr 
noi ta itr if invited==1
noi table itr if invited==1, c(mean urban mean old) 

***************************
*heterogeneity

*Tables 4 and 5 not in XL
***************************

noi dis "This is the heterogeneity analysis"
***************
noi dis "Tab4 urban rural
noi dis "URBAN"
*FS
noi reghdfe letterr invited r if urban==1, vce(robust) absorb(gpid)  
noi reghdfe lrr invited r if urban==1, vce(robust) absorb(gpid)
*ITT
noi reghdfe outcome_correct invited r if urban==1, vce(robust) absorb(gpid)
*IV
noi ivreghdfe outcome_correct (letterr lrr=invited r) if urban==1, robust absorb(gpid) ffirst 

noi dis "RURAL"
*FS
noi reghdfe letterr invited r if urban==0, vce(robust) absorb(gpid)  
noi reghdfe lrr invited r if urban==0, vce(robust) absorb(gpid)
*ITT
noi reghdfe outcome_correct invited r if urban==0, vce(robust) absorb(gpid)
*IV
noi ivreghdfe outcome_correct (letterr lrr=invited r) if urban==0, robust absorb(gpid) ffirst 

*SUEST the ITT and IV

noi dis "suest letter FS"
reg letterr invited r i.gpid if urban==1
est store a
reg letterr invited r i.gpid if urban==0
est store b
suest a b, robust
noi test [a_mean]invited=[b_mean]invited
noi test [a_mean]r=[b_mean]r

noi dis "suest reminder FS"
reg lrr invited r i.gpid if urban==1
est store a
reg lrr invited r i.gpid if urban==0
est store b
suest a b, robust
noi test [a_mean]invited=[b_mean]invited
noi test [a_mean]r=[b_mean]r

noi dis "suest itt"
reg outcome_correct invited r i.gpid if urban==1
est store a
reg outcome_correct invited r i.gpid if urban==0
est store b
suest a b, robust
noi test [a_mean]invited=[b_mean]invited
noi test [a_mean]r=[b_mean]r

*JOINT ESTIMATION

ge letterr_u = letterr*urban
ge letterr_r = letterr*(1-urban)

ge lrr_u = lrr*urban
ge lrr_r = lrr*(1-urban)

ge invited_u = invited*urban
ge invited_r = invited*(1-urban)

ge r_u = r*urban
ge r_r = r*(1-urban)

noi dis "FS"
noi reghdfe letterr_u invited_u invited_r r_u r_r, vce(robust) absorb(i.gpid##i.urban)  
noi test invited_u=invited_r
noi test r_u=r_r
noi reghdfe letterr_r invited_u invited_r r_u r_r, vce(robust) absorb(i.gpid##i.urban) 
noi test invited_u=invited_r
noi test r_u=r_r
noi reghdfe lrr_u invited_u invited_r r_u r_r, vce(robust) absorb(i.gpid##i.urban) 
noi test invited_u=invited_r
noi test r_u=r_r
noi reghdfe lrr_r invited_u invited_r r_u r_r, vce(robust) absorb(i.gpid##i.urban) 
noi test invited_u=invited_r
noi test r_u=r_r

noi dis "ITT"
noi reghdfe outcome_correct invited_u invited_r r_u r_r, vce(robust) absorb(i.gpid##i.urban)
noi test invited_u=invited_r
noi test r_u=r_r

noi dis "IV"
noi ivreghdfe outcome_correct (letterr_u letterr_r lrr_u lrr_r=invited_u invited_r r_u r_r), robust absorb(i.gpid##i.urban) 
noi test letterr_u=letterr_r 
noi test lrr_u=lrr_r 


noi dis "Tab 5 AGE - 50+ = old"

noi dis "OLD"
*FS
noi reghdfe letterr invited r if old==1, vce(robust) absorb(gpid) 
noi reghdfe lrr invited r if old==1, vce(robust) absorb(gpid)
*ITT
noi reghdfe outcome_correct invited r if old==1, vce(robust) absorb(gpid)
*IV
noi ivreghdfe outcome_correct (letterr lrr=invited r) if old==1, robust absorb(gpid) ffirst 


noi dis "YOUNG"
*FS
noi reghdfe letterr invited r if old==0, vce(robust) absorb(gpid) 
noi reghdfe lrr invited r if old==0, vce(robust) absorb(gpid)
*ITT
noi reghdfe outcome_correct invited r if old==0, vce(robust) absorb(gpid)
*IV
noi ivreghdfe outcome_correct (letterr lrr=invited r) if old==0, robust absorb(gpid) ffirst 

noi dis "suest letter FS"
reg letterr invited r i.gpid if old==1
est store a
reg letterr invited r i.gpid if old==0
est store b
suest a b, robust
noi test [a_mean]invited=[b_mean]invited
noi test [a_mean]r=[b_mean]r

noi dis "suest reminder FS"
reg lrr invited r i.gpid if old==1
est store a
reg lrr invited r i.gpid if old==0
est store b
suest a b, robust
noi test [a_mean]invited=[b_mean]invited
noi test [a_mean]r=[b_mean]r

noi dis "suest itt"
reg outcome_correct invited r i.gpid if old==1
est store a
reg outcome_correct invited r i.gpid if old==0
est store b
suest a b, robust
noi test [a_mean]invited=[b_mean]invited
noi test [a_mean]r=[b_mean]r

ge letterr_o = letterr*old
ge letterr_y = letterr*(1-old)

ge lrr_o = lrr*old
ge lrr_y = lrr*(1-old)

ge invited_o = invited*old
ge invited_y = invited*(1-old)

ge r_o = r*old
ge r_y = r*(1-old)


noi dis "FS"
noi reghdfe letterr_o invited_o invited_y r_o r_y, vce(robust) absorb(i.gpid##i.old)  
noi test invited_o=invited_y
noi test r_o=r_y
noi reghdfe letterr_y invited_o invited_y r_o r_y, vce(robust) absorb(i.gpid##i.old) 
noi test invited_o=invited_y
noi test r_o=r_y
noi reghdfe lrr_o invited_o invited_y r_o r_y, vce(robust) absorb(i.gpid##i.old) 
noi test invited_o=invited_y
noi test r_o=r_y
noi reghdfe lrr_y invited_o invited_y r_o r_y, vce(robust) absorb(i.gpid##i.old) 
noi test invited_o=invited_y
noi test r_o=r_y

noi dis "ITT"
noi reghdfe outcome_correct invited_o invited_y r_o r_y, vce(robust) absorb(i.gpid##i.old)
noi test invited_o=invited_y
noi test r_o=r_y

noi dis "IV"
noi ivreghdfe outcome_correct (letterr_o letterr_y lrr_o lrr_y=invited_o invited_y r_o r_y), robust absorb(i.gpid##i.old) 
noi test letterr_o=letterr_y
noi test lrr_o=lrr_y

drop old



***********************************
*Table S3. Robustness tests. Clustering standard errors by GP. 
noi dis "S3. Robustness tests. Clustering standard errors by GP."

noi dis "The effects of invitation letters and of letter and reminder combinations on take-up"
capture erase TabS3.txt
capture erase TabS3.xls
noi dis "ITT"
noi areg outcome_correct invited r, cluster(gpid) absorb(gpid)
noi test invited r
local pj = r(p)
noi su outcome_correct if invited==0
local mean = r(mean)
outreg2 using TabS3.xls, excel append dec(3) nocon nor2 keep(invited r) ///
addstat("P-value joint", `pj', "Mean control group", `mean') 

capture erase TabS3.txt

*********
*Table S4 not in XL
noi{

dis "S4 nonlinear models"
xi: dprobit outcome_correct invited r i.gpid, robust 
test invited r
xi: logit outcome_correct invited r i.gpid, robust 
test invited r
margins, dydx(i r)
}


***********************************
*Table S5. Robustness tests. Including only subjects who turned 30 from May 2017 onwards.
noi dis "S5.	 Robustness tests. Including only subjects who turned 30 from May 2017 onwards."

capture erase TabS5.txt
capture erase TabS5.xls
*ITT
noi dis "ITT"
noi areg outcome_correct invited r if firstinv==1, robust absorb(gpid)
noi test invited r
local pj = r(p)
noi su outcome_correct if invited==0 & firstinv==1
local mean = r(mean)
outreg2 using TabS5.xls, excel append dec(3) nocon nor2 keep(invited r) ///
addstat("P-value joint", `pj',"Mean control group", `mean') 

noi reghdfe outcome_correct invited r if firstinv==1, vce(robust) absorb(gpid urban age)
noi test invited r
local pj = r(p)
noi su outcome_correct if invited==0 & firstinv==1
local mean = r(mean)
outreg2 using TabS5.xls, excel append dec(3) nocon nor2 keep(invited r) ///
addstat("P-value joint", `pj',"Mean control group", `mean') 

capture erase TabS5.txt


**************************
*TABLE 3 not in XL
noi dis "Table 3 Xs by treatment and screening status"
noi{
	cap drop old
	qui ge  old= age>=50

	table outcome_correct if invited==0, c(mean urban mean old)
	table outcome_correct if invited==1, c(mean urban mean old)

}

noi log close
}

